@@ -380,9 +380,10 @@ class SenderQQ(QThread):
     def send(self, param):
         self.logger.debug("sending")
         param["source"]=APP_KEY
+        
         param["clientip"]="127.0.0.1"
-        #param["jing"]=param["lat"]
-        #param["wei"]=param["long"]
+        param["jing"]=param["long"]
+        param["wei"]=param["lat"]
         
         if param["timelineType"]==4:
             param["content"]=param["comment"]
@@ -452,4 +453,4 @@ class SenderQQ(QThread):
         #print "delete_follower"
         param={}
         param["name"]=screen_name
-        self.api.friends.delete(**param)
\ No newline at end of file
+        self.api.friends.delete(**param)
