@@ -1264,20 +1264,29 @@ class MaoboApp(QApplication):
     '''
 
     def send_a_status(self):
-        self.logger.debug("send_a_status")
-        param=self.newStatusWin.output_param()
         if self.sender.isRunning():
-            self.logger.debug("sender is running!")
             self.show_notice("后台运行中，请稍候重试")
             return
         self.newStatusWin.enable_send(False)
+
+        param=self.newStatusWin.output_param()
+        
+        # append gps info.
+        import os
+        ret = os.popen('python location.gps.py').read()
+        tmpParam = ret.split(',')
+        print 'lat:' + tmpParam[0]
+        print 'long:' + tmpParam[1]
+        
+        param['lat'] = tmpParam[0]
+        param['long'] = tmpParam[1]
         
         self.sender.initialize(self.currentAccount["id"],param)
         
         self.show_notice("微博发送中...")
         self.set_windows_status(1)
         self.sender.start()
-
+        
     def send_finished(self,completed):
         self.logger.debug("send_finished")
         self.set_windows_status(0)
